featureflags.evaluations package
================================

Submodules
----------

featureflags.evaluations.auth\_target module
--------------------------------------------

.. automodule:: featureflags.evaluations.auth_target
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.clause module
--------------------------------------

.. automodule:: featureflags.evaluations.clause
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.constants module
-----------------------------------------

.. automodule:: featureflags.evaluations.constants
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.distribution module
--------------------------------------------

.. automodule:: featureflags.evaluations.distribution
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.enum module
------------------------------------

.. automodule:: featureflags.evaluations.enum
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.feature module
---------------------------------------

.. automodule:: featureflags.evaluations.feature
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.prerequisite module
--------------------------------------------

.. automodule:: featureflags.evaluations.prerequisite
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.segment module
---------------------------------------

.. automodule:: featureflags.evaluations.segment
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.serve module
-------------------------------------

.. automodule:: featureflags.evaluations.serve
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.serving\_rule module
---------------------------------------------

.. automodule:: featureflags.evaluations.serving_rule
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.strategy module
----------------------------------------

.. automodule:: featureflags.evaluations.strategy
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.tag module
-----------------------------------

.. automodule:: featureflags.evaluations.tag
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.target module
--------------------------------------

.. automodule:: featureflags.evaluations.target
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.target\_attributes module
--------------------------------------------------

.. automodule:: featureflags.evaluations.target_attributes
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.target\_map module
-------------------------------------------

.. automodule:: featureflags.evaluations.target_map
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.variation module
-----------------------------------------

.. automodule:: featureflags.evaluations.variation
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.variation\_map module
----------------------------------------------

.. automodule:: featureflags.evaluations.variation_map
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.evaluations.weighted\_variation module
---------------------------------------------------

.. automodule:: featureflags.evaluations.weighted_variation
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: featureflags.evaluations
   :members:
   :undoc-members:
   :show-inheritance:
